@@ -2,7 +2,6 @@ import asyncio
 from dataclasses import dataclass, field
 from datetime import timedelta
 import logging
-from typing import Optional
 
 logger = logging.getLogger(__name__)
 
@@ -11,8 +10,6 @@ logger = logging.getLogger(__name__)
 class Throttle:
     release_rate: int
     release_freq: timedelta
-    debounce_interval: Optional[timedelta] = None
-    debounce_statuses: Optional[list] = None
     _semaphore: asyncio.BoundedSemaphore = field(init=False)
     _task: asyncio.Task = field(init=False)
 
